pub(crate) fn dynimage_conversion_8bit(
img: &DynamicImage,
) -> Option<DynamicImage>Expand description
Implement dynimage_conversion_sequence for the common case of supporting only 8-bit colors
(with and without alpha).
pub(crate) fn dynimage_conversion_8bit(
img: &DynamicImage,
) -> Option<DynamicImage>Implement dynimage_conversion_sequence for the common case of supporting only 8-bit colors
(with and without alpha).