pub struct MethodSealedToImage;Expand description
Nominally public but DO NOT expose this type.
To be somewhat sure here’s a compile fail test:
ⓘ
use image::MethodSealedToImage;ⓘ
use image::io::MethodSealedToImage;The same implementation strategy for a partially public trait is used in the standard library,
for the different effect of forbidding Error::type_id overrides thus making them reliable for
their calls through the dyn version of the trait.
Read more: https://predr.ag/blog/definitive-guide-to-sealed-traits-in-rust/